@@ -40,6 +40,8 @@ egfr.fas.cr <- function(
 
   ##################################################################
   # CHECK FUNCTION INPUT: BEGIN
+
+  if(!service.check_equal_length(creatinine, age, sex)) stop("The length of variables should be equal.")
   
   # check whether all obligatory argument(s) is(are) defined by user
   fx_params <- c("creatinine", "age", "sex") # List of obligatory function params which have to be defined by user at the function call
@@ -55,22 +57,16 @@ egfr.fas.cr <- function(
   # check the range of creatinine_units
   service.check_param_arguments(creatinine_units, c("mg/dl", "micromol/l", "mmol/l"))
 
-  # Check whether numerical arguments inputed by user are fine (weight, height etc have to be positive numbers)
-  service.check_params_numeric(age, creatinine)
-  
-  
-  # check plausible biologic boundaries (by functions in the service.check_plausibility.R):
-  #   check and inform user whether any values out of boundaries were substituted by NA
-  #   after the check change the value to boundaries in the possible range (i.e. age > 0 and < 100)
-  # age
-  # first: general check and tidy: age <0 OR age >100
-  age <- service.check_plausibility.age(age, max_age)
-  # second: since this eGFR equation was developed and validated for adults only, notify user if any children were found, and exclude them from calculation
-  suspiciosly_low <- service.count_lower_threshold(age, 2)
-  if(suspiciosly_low > 0) cat(service.output_message(suspiciosly_low, "age <2 years", "NA"))
-  age <- service.strict_to_numeric_threshold_lower(age, 2)
-  # creatinine
-  service.check_plausibility.creatinine(creatinine)
+  # check plausible biologic boundaries
+  age <- service.check_and_correct_numeric(age, "age",
+    rules = c(
+      non_negative = TRUE,
+      lower_than = max_age,
+      greater_than = 2,
+      children_too_young = 2
+    )
+  )
+  creatinine <- service.check_and_correct_numeric(creatinine, "creatinine")
 
   # CHECK FUNCTION INPUT: END
   ##################################################################
@@ -155,6 +151,8 @@ egfr.fas.cys <- function(
   ##################################################################
   # CHECK FUNCTION INPUT: BEGIN
   
+  if(!service.check_equal_length(cystatin, age)) stop("The length of variables should be equal.")
+
   # check whether all obligatory argument(s) is(are) defined by user
   fx_params <- c("cystatin", "age") # List of obligatory function params which have to be defined by user at the function call
   args <- names(as.list(match.call())[-1]) # take all params defined by user from the function
@@ -172,33 +170,24 @@ egfr.fas.cys <- function(
 
   service.check_param_arguments(equation_type, c("precise", "simplified") )
 
-  # Check whether numerical arguments inputed by user are fine (weight, height etc have to be positive numbers)
-  service.check_params_numeric(age, cystatin)
-  
-  
-  # check plausible biologic boundaries (by functions in the service.check_plausibility.R):
-  #   check and inform user whether any values out of boundaries were substituted by NA
-  #   after the check change the value to boundaries in the possible range (i.e. age > 0 and < 100)
-  # age
-  # first: general check and tidy: age <0 OR age >100
-  age <- service.check_plausibility.age(age, max_age)
-  # second: since this eGFR equation was developed and validated for adults only, notify user if any children were found, and exclude them from calculation
-  suspiciosly_low <- service.count_lower_threshold(age, 2)
-  if(suspiciosly_low > 0) cat(service.output_message(suspiciosly_low, "age <2 years", "NA"))
-  age <- service.strict_to_numeric_threshold_lower(age, 2)
-  service.check_plausibility.creatinine(cystatin)
+  # check plausible biologic boundaries
+  age <- service.check_and_correct_numeric(age, "age",
+    rules = c(
+      non_negative = TRUE,
+      lower_than = max_age,
+      greater_than = 2,
+      children_too_young = 2
+    )
+  )
+  cystatin <- service.check_and_correct_numeric(cystatin, "cystatin C")
 
   # CHECK FUNCTION INPUT: END
   ##################################################################
 
-
-  #
-  # repeat creatinine_units according to the length of the file, since the creatinine_units is defined either by user or by default value as a single value for the whole function
-  #
   cystatin_units <- rep(cystatin_units, length(cystatin))
   
   #
-  # convert creatinine units if necessary
+  # convert cystatin units if necessary
   #
   cystatin <- service.convert_cystatin(cystatin, cystatin_units)
 
@@ -278,6 +267,8 @@ egfr.fas.cr_cys <- function(
 
   ##################################################################
   # CHECK FUNCTION INPUT: BEGIN
+
+  if(!service.check_equal_length(creatinine, cystatin, age, sex)) stop("The length of variables should be equal.")
   
   # check whether all obligatory argument(s) is(are) defined by user
   fx_params <- c("creatinine", "cystatin", "age", "sex") # List of obligatory function params which have to be defined by user at the function call
@@ -299,23 +290,17 @@ egfr.fas.cr_cys <- function(
   service.check_param_arguments(creatinine_units, c("mg/dl", "micromol/l", "mmol/l"))
   service.check_param_arguments(cystatin_units, c("mg/l", "nanomol/l"))
 
-  # Check whether numerical arguments inputed by user are fine (weight, height etc have to be positive numbers)
-  service.check_params_numeric(age, creatinine, cystatin)
-  
-  
-  # check plausible biologic boundaries (by functions in the service.check_plausibility.R):
-  #   check and inform user whether any values out of boundaries were substituted by NA
-  #   after the check change the value to boundaries in the possible range (i.e. age > 0 and < 100)
-  # age
-  # first: general check and tidy: age <0 OR age >100
-  age <- service.check_plausibility.age(age, max_age)
-  # second: since this eGFR equation was developed and validated for adults only, notify user if any children were found, and exclude them from calculation
-  suspiciosly_low <- service.count_lower_threshold(age, 2)
-  if(suspiciosly_low > 0) cat(service.output_message(suspiciosly_low, "age <2 years", "NA"))
-  age <- service.strict_to_numeric_threshold_lower(age, 2)
-  # creatinine
-  service.check_plausibility.creatinine(creatinine)
-  service.check_plausibility.creatinine(cystatin)
+  # check plausible biologic boundaries
+  age <- service.check_and_correct_numeric(age, "age",
+    rules = c(
+      non_negative = TRUE,
+      lower_than = max_age,
+      greater_than = 2,
+      children_too_young = 2
+    )
+  )
+  creatinine <- service.check_and_correct_numeric(creatinine, "creatinine")
+  cystatin <- service.check_and_correct_numeric(cystatin, "cystatin C")
 
   # CHECK FUNCTION INPUT: END
   ##################################################################
@@ -331,7 +316,7 @@ egfr.fas.cr_cys <- function(
   #
   # convert creatinine units if necessary
   #
-  creatinine <- service.convert_creatinine(creatinine, creatinine_units)
+  creatinine <- service.convert_creatinine(creatinine, creatinine_units, creatinine_reference_units = "micromol/l")
   cystatin <- service.convert_cystatin(cystatin, cystatin_units)
 
   # define q for children in micromol/L, age is the index of value, so q_boys[1] is 23 for 1-year old, q_boys[7] is 39 for 7-years old, etc
@@ -339,7 +324,6 @@ egfr.fas.cr_cys <- function(
   q_girls <- c(23, 26, 27, 30, 34, 36, 39, 41, 43, 45, 47, 50, 52, 54, 57, 59, 61, 61, 62)
 
   # convert creatinine units
-  creatinine <- service.convert_creatinine(creatinine, creatinine_units, creatinine_reference_units = "micromol/l")
   # no need to convert q_boys and q_girls because creatinine was forced to be in micromol/l
 
   # q for all ages
